==> express-jefferson-1.1.0.tgz: package/jefferson.js <==
"use strict";

/**
 * Declaratively initializes routes in an express app
 */
var debug = require("debug")("jefferson");

module.exports = function (app, conf) {
    if (!app) {
        throw new Error("app parameter must be supplied");
    }
    if (!conf) {
        throw new Error("application configuration must be supplied");
    }

    var proxies = conf.proxies;

    var possiblyProxy = function (middleware) {
        if (!proxies || !proxies.length) {
            return middleware;
        }
        return middleware.map(function (mw) {
            var lastProxy = proxies[proxies.length - 1].init(mw);
            for (var i = proxies.length - 2; i >= 0; i--) {
                lastProxy = proxies[i].init(lastProxy);
            }
            return lastProxy;
        });
    };

    var wireRoute = function (routeName, route) {
        var method = route.method.toLowerCase(),
            path = route.path,
            middleware = possiblyProxy(route.middleware);
        //jscs:disable
        debug("routing " + routeName + " - " + method + " " + path + " - " + middleware.length + " middlewares");
        //jscs:enable
        app[method](path, middleware);
    };
    var wireRoutes = function () {
        var routeNames = Object.keys(conf.routes);
        //jscs:disable
        debug("wiring " + routeNames.length + " routes");
        //jscs:enable
        routeNames.forEach(function (routeName) {
            return wireRoute(routeName, conf.routes[routeName]);
        });
    };

    wireRoutes();
};

==> express-jefferson-1.1.4.tgz: package/jefferson.js <==
"use strict";

/**
 * Declaratively initializes routes in an express app
 */
var debug = require("debug")("jefferson");

module.exports = function (app, conf) {
    if (!app) {
        throw new Error("app parameter must be supplied");
    }
    if (!conf) {
        throw new Error("application configuration must be supplied");
    }

    var proxies = conf.proxies;

    var possiblyProxy = function (middleware) {
        if (!proxies || !proxies.length) {
            return middleware;
        }
        return middleware.map(function (mw) {
            var initProxy = function (proxy, delegate) {
                return proxy.init(delegate, proxy.config);
            };

            var lastProxy = initProxy(proxies[proxies.length - 1], mw);
            for (var i = proxies.length - 2; i >= 0; i--) {
                lastProxy = initProxy(proxies[i], lastProxy);
            }
            return lastProxy;
        });
    };

    var wireRoute = function (routeName, route) {
        var method = route.method.toLowerCase(),
            path = route.path,
            middleware = possiblyProxy(route.middleware);
        //jscs:disable
        debug("routing " + routeName + " - " + method + " " + path + " - " + middleware.length + " middlewares");
        //jscs:enable
        app[method](path, middleware);
    };
    var wireRoutes = function () {
        var routeNames = Object.keys(conf.routes);
        //jscs:disable
        debug("wiring " + routeNames.length + " routes");
        //jscs:enable
        routeNames.forEach(function (routeName) {
            return wireRoute(routeName, conf.routes[routeName]);
        });
    };

    wireRoutes();
};
